@@ -29,13 +29,13 @@ def list_projects():
 def introduce():
     """ Welcomes a new user to the {name} tutorial."""
     config = api.get_local_config()
-    l(config['introduction'], 'green')
+    l(config['introduction' + '\n'], 'green')
 
 
 def show_task():
     """ Informs the user of their current task."""
     task = api.get_task()
-    l(task['instruction'], 'cyan')
+    l(task['instruction' + '\n'], 'cyan')
 
 
 
@@ -105,6 +105,8 @@ def progress():
         return
     else:
         for j in full_local_config['lessons']:
+            for i in j['tasks']:
+                ###
             text = colored(j['name'], 'blue')
             print('  [' + i_text + ']: ' + text)
         print('\n')
@@ -160,7 +162,7 @@ def main():
 if __name__ == '__main__':
 
     help_message = (
-        'Need to add arguments for lrn, possible arguments:\n\n' 
+        'Available commands:\n\n' 
         '\tlist     ----  Gives a list of all available tutorials.\n'  
         '\tstart    ----  Starts a lesson.\n'  
         '\tprogress ----  Displays your lesson progress in a tutorial\n' 
